@@ -1,23 +1,25 @@
 import os, sys
 import traceback
-from collections import OrderedDict, deque
+from collections import OrderedDict, namedtuple
 import json
-import random
 import argparse
-import time
-import vlc
 
-from iheart import (
-	__version__,
-	vlc_is_installed,
-	iHeart,
-	Track,
-	Station,
-	LiveStation,
-	SongStation,
-	ArtistStation,
+
+from .stations import (
+	iHeartLiveStation,
+	iHeartSongStation,
+	iHeartArtistStation,
+	LocalPlaylist,
+
+	aNONradio,
+	InternetRadio
 )
-from iheart.colors import Colors
+
+from .stations.iheart_radio import client as iheart_client
+
+from .player import vlc_is_installed
+from .colors import Colors
+from . import __version__
 
 
 try:
@@ -25,7 +27,7 @@ try:
 except ImportError:
 	import termios
 	import tty
-	def getch():  # getchar(), getc(stdin)  #PYCHOK flake
+	def getch(): # getchar(), getc(stdin)  #PYCHOK flake
 		fd = sys.stdin.fileno()
 		old = termios.tcgetattr(fd)
 		try:
@@ -41,6 +43,8 @@ wipeline = lambda:sys.stdout.write("\33[2K\r")
 app_msg_color = lambda m: Colors.colorize(m, Colors.YELLOW, bold=False)
 app_critical_color = lambda m: Colors.colorize(m, Colors.RED, bold=False)
 
+CategoryControl = namedtuple('CategoryControl', ['name', 'shorthand'])
+
 
 WELCOME_MSG = '''Welcome to iHeart cli player (v{})!
 Type '?' during playback to show available commands.'''.format(__version__)
@@ -48,6 +52,17 @@ Type '?' during playback to show available commands.'''.format(__version__)
 WELCOME_MSG = app_msg_color(WELCOME_MSG)
 
 
+DATADIR = os.path.join(
+	os.environ.get('APPDATA') or
+	os.environ.get('XDG_DATA_HOME') or
+	os.path.join(os.environ['HOME'], '.local', 'share'),
+	"iheartcli"
+)
+if not os.path.isdir(DATADIR):
+	os.makedirs(DATADIR)
+
+
+
 def _print_error(msg):
 	print(" {} {}".format(
 		Colors.colorize("x", Colors.RED, bold=True),
@@ -56,167 +71,52 @@ def _print_error(msg):
 
 
 
-class Playlist(ArtistStation):
-	'''Json stored playlist implementation using ArtistRadio class'''
-	def __init__(self, playlist_dict):
-		self.__dict = playlist_dict
-		self.name = playlist_dict['name']
-		super().__init__({'id': self.name, 'name': self.name, 'user_id':None})
-		self.track_list = deque([Track(trk_dict) for trk_dict in playlist_dict['track_dict_list']]) # deque so as to use rotate
-		self.tracks_to_play = self.track_list.copy() # make copy to implement shuffle
-		self.shuffle = False
-		self.now_playing_id = None
-
-	def get_dict(self):
-		return self.__dict
-
-	def __str__(self):
-		return "<Playlist: {}> {}".format(
-			Colors.colorize(self.id, Colors.CYAN),
-			Colors.colorize("[Shuffle]", Colors.PINK) if self.shuffle else '',
-		)
-
-	def iter_tracks(self):
-		while True:
-			new_track = self.tracks_to_play[0]
-			self.now_playing_id = new_track.id
-			yield new_track
-			self.tracks_to_play.rotate(-1) # rotate left to go to next track
-
-	def remove_track(self, track_id):
-		def filter_func(t):
-			return t.id != track_id
-		self.track_list = deque(filter(filter_func, self.track_list))
-		self.tracks_to_play = deque(filter(filter_func, self.tracks_to_play))
-
-
-	def toggle_shuffle(self):
-		self.shuffle = not self.shuffle
-		if self.shuffle:
-			random.shuffle(self.tracks_to_play) # shuffle playlist
-		else: # shuffle off
-			# if there is a song playing in shuffle mode,
-			# rotate tracklist such that the playlist continues from the current track
-			current_idx = 0
-			if self.now_playing_id is not None:
-				for i, t in enumerate(self.track_list):
-					if t.id==self.now_playing_id:
-						current_idx = i
-						break
-
-			self.tracks_to_play = self.track_list.copy() # make copy of original track list
-			self.tracks_to_play.rotate(-1*current_idx) # rotate left to current track
-
-	def jump_to(self, idx):
-		if idx < len(self.track_list):
-			track = self.track_list[idx]
-			for i, t in enumerate(self.tracks_to_play):
-				if t.id==track.id:
-					self.tracks_to_play.rotate(-1*(i-1)) # rotate left so that selected track will play next
-					self.forward() # then trigger jump to next song
-					break
-
-
-
-class aNONradio(Station):
-
-	def __init__(self):
-		station_dict = {
-			'id': 'aNON',
-			'user_id': 'aNON',
-			'name': 'aNONradio.net',
-			'mrl': "http://anonradio.net:8000/anonradio"
-		}
-		super().__init__(station_dict)
-
-	def __str__(self):
-		player = self.get_player()
-		if player.is_playing():
-			media = player.plr.get_media()
-			if not media.is_parsed():
-				media.parse()
-			desc = '"{}" on "{}"'.format(
-				Colors.colorize(str(media.get_meta(vlc.Meta.NowPlaying)), Colors.YELLOW, bold=True),
-				Colors.colorize(str(media.get_meta(vlc.Meta.Title)), Colors.GREEN, bold=True),
-			)
-		else:
-			desc = Colors.colorize(self.mrl, Colors.BLUE, bold=True)
-		decor = Colors.colorize("**", Colors.RED)
-		return "{} {}: {} {}".format(
-			decor,
-			Colors.colorize(self.name, Colors.CYAN, bold=True),
-			desc,
-			decor
-		)
-
-	def forward(self):
-		# disable forwarding
-		pass
-
-	def rewind(self):
-		# disable rewinding
-		pass
-
-
-
-class iHeart_Storage(object):
+class iRadio_Storage(object):
 
 	DATA = {
 		'last_played': None,
 		'playlists': {},
 	}
 
-	CONFIG = {}
+	_STATION_CLASS_MAP = {s.__name__: s for s in [
+		iHeartArtistStation,
+		iHeartLiveStation,
+		iHeartSongStation,
+		LocalPlaylist,
+		aNONradio,
+		InternetRadio,
+	]}
 
-	_STATION_CLASS_MAP = {
-		ArtistStation.__name__: ArtistStation,
-		LiveStation.__name__: LiveStation,
-		SongStation.__name__: SongStation,
-		Station.__name__: Station,
-
-		Playlist.__name__: Playlist,
-		aNONradio.__name__: aNONradio,
-	}
-
-	def __init__(self, configdir, debug=False):
-		self._debug = debug
+	def __init__(self, configdir):
+		self._debug = os.environ.get('RADIO_DEBUG') == "1"
 		self.configdir = configdir
-		self.CONFIG = self._load_config()
-		self.DATA = self._load_data()
+		self._config = self._load_config()
+		self._data = self._load_data()
 
 	def _load_config(self):
-		if not os.path.isdir(self.configdir): os.makedirs(self.configdir)
+		if not os.path.isdir(self.configdir):
+			os.makedirs(self.configdir)
 		temp_conf = {
 			'last-played-file': os.path.join(self.configdir, 'last_played.json'),
 			'playlist-dir-path': os.path.join(self.configdir, 'playlists'),
 		}
-		conf_file = os.path.join(self.configdir, 'config.json')
-		try:
-			with open(conf_file, 'r') as conf:
-				for k,v in json.load(conf).items():
-					temp_conf[k] = v
-		except Exception as e:
-			if self._debug: print(e)
 		if not os.path.isdir(temp_conf['playlist-dir-path']):
 			os.makedirs(temp_conf['playlist-dir-path'])
-
-		with open(conf_file, 'w') as conf:
-			json.dump(temp_conf, conf, indent=4)
 		return temp_conf
 
 	def _load_data(self):
 		default_data = self.DATA.copy()
-		if os.path.isfile(self.CONFIG['last-played-file']):
+		if os.path.isfile(self._config['last-played-file']):
 			try:
-				with open(self.CONFIG['last-played-file'], 'r') as conf:
+				with open(self._config['last-played-file'], 'r') as conf:
 					default_data['last_played'] = json.load(conf, object_pairs_hook=OrderedDict)
 			except Exception as e:
 				if self._debug: print(e)
-		for f in os.listdir(self.CONFIG['playlist-dir-path']):
+		for f in os.listdir(self._config['playlist-dir-path']):
 			if f.endswith('.playlist.json'):
 				pl_name = f.replace(".playlist.json", "")
 				try:
-					with open(os.path.join(self.CONFIG['playlist-dir-path'], f), 'r') as pl:
+					with open(os.path.join(self._config['playlist-dir-path'], f), 'r') as pl:
 						default_data['playlists'][pl_name] = json.load(pl, object_pairs_hook=OrderedDict)
 				except Exception as e:
 					if self._debug: print(e)
@@ -224,12 +124,12 @@ class iHeart_Storage(object):
 
 	def write(self):
 		for pl_name, obj in self.get_playlists().items():
-			pl_file = os.path.join(self.CONFIG['playlist-dir-path'], '{}.playlist.json'.format(pl_name))
+			pl_file = os.path.join(self._config['playlist-dir-path'], '{}.playlist.json'.format(pl_name))
 			with open(pl_file, 'w') as pl:
 				json.dump(obj, pl, indent=4)
 
-		with open(self.CONFIG['last-played-file'], 'w') as conf:
-			conf.write(json.dumps(self.DATA['last_played'], indent=4))
+		with open(self._config['last-played-file'], 'w') as conf:
+			conf.write(json.dumps(self._data['last_played'], indent=4))
 
 	def station_to_dict(self, station_instance):
 		d = station_instance.get_dict()
@@ -243,7 +143,7 @@ class iHeart_Storage(object):
 		return self._STATION_CLASS_MAP[d['__name__']](d)
 
 	def current_track_to_dict(self, station_instance):
-		if isinstance(station_instance, (ArtistStation, SongStation)):
+		if isinstance(station_instance, (iHeartArtistStation, iHeartSongStation)):
 			track = station_instance.get_current_track()
 			if track:
 				return self.station_to_dict(track)
@@ -255,27 +155,28 @@ class iHeart_Storage(object):
 	def update_last_played(self, track):
 		if not isinstance(track, dict):
 			track = self.station_to_dict(track)
-		self.DATA['last_played'] = track
+		self._data['last_played'] = track
 		self.write()
 
 	def add_to_playlist(self, playlist_name, track):
 		if not isinstance(track, dict):
 			track = self.current_track_to_dict(track)
-		if playlist_name not in self.DATA['playlists']:
-			self.DATA['playlists'][playlist_name] = OrderedDict()
-		track_id = str(track['__id__']) # json.dump automatically converts keys to strings. make it explicit!
-		if track_id not in self.DATA['playlists'][playlist_name]:
-			self.DATA['playlists'][playlist_name][track_id] = track #__id__ is unique iheart id
-		self.write()
+		if playlist_name not in self._data['playlists']:
+			self._data['playlists'][playlist_name] = OrderedDict()
+		if '__id__' in track:
+			track_id = str(track['__id__']) # json.dump automatically converts keys to strings. make it explicit!
+			if track_id not in self._data['playlists'][playlist_name]:
+				self._data['playlists'][playlist_name][track_id] = track #__id__ is unique iheart id
+			self.write()
 
 	def delete_from_playlist_by_id(self, playlist_name, track_id):
 		track_id = str(track_id) # json.dump automatically converts keys to strings. make it explicit!
-		if playlist_name in self.DATA['playlists'] and track_id in self.DATA['playlists'][playlist_name]:
-			del self.DATA['playlists'][playlist_name][track_id]
+		if playlist_name in self._data['playlists'] and track_id in self._data['playlists'][playlist_name]:
+			del self._data['playlists'][playlist_name][track_id]
 			self.write()
 
 	def get_playlists(self):
-		return self.DATA['playlists']
+		return self._data['playlists']
 
 
 
@@ -284,18 +185,63 @@ class ExitException(Exception):
 	pass
 
 
+
+
+class iHeart(object):
+
+	TRACKS = 'tracks'
+	ARTISTS = 'artists'
+	STATIONS = 'stations'
+
+	# # other choices - Not implemented yet
+	# PLAYLISTS = 'playlists'
+	# ALBUMS = 'albums'
+	# PODCASTS = "podcasts"
+	# FEATURED_STATIONS = "featuredStations"
+	# TALKSHOWS = "talkShows"
+	# TALKTHEMES = "talkThemes"
+
+	def __init__(self, uuid_filepath):
+		self.user = iheart_client.ilogin(uuid_filepath=uuid_filepath)
+		self.user_id = self.user['profileId']
+
+	def search(self, keyword, category=None, startIndex=0):
+		if category is None: category = self.ARTISTS
+		search_res = iheart_client.isearch(keyword, startIndex=startIndex)
+
+		if category==self.STATIONS:
+			station_class = iHeartLiveStation
+		elif category==self.ARTISTS:
+			station_class = iHeartArtistStation
+		elif category==self.TRACKS:
+			station_class = iHeartSongStation
+		else:
+			# return search_res['results'][category]
+			raise NotImplementedError("'{}' not implemented yet")
+
+		out = []
+		for result in search_res['results'][category]:
+			result['user_id'] = self.user_id
+			out.append(station_class(result))
+		return out
+
+
+
+
 class iHeart_CLI(iHeart):
 
-	PLAYLISTS = 'playlists' # this is not iHeart playlists. it is used for local playlists implemented in __main__.py
+	PLAYLISTS = 'playlists' # this is not iHeart playlists. it is used for local playlists implemented in stations/iheart_radio/playlist.py
 	ANON = 'aNONradio'
+	INTERNET = 'internet-radio'
 
 	CATEGORIES = OrderedDict({
-		iHeart.ARTISTS: 'Artist Radio',
-		iHeart.TRACKS: 'Song Radio',
-		iHeart.STATIONS: "Live Radio",
+		iHeart.ARTISTS: CategoryControl('Artist Radio', 'a'),
+		iHeart.TRACKS: CategoryControl('Song Radio', 's'),
+		iHeart.STATIONS: CategoryControl("Live Radio", 'l'),
 		# non-iheart station types
-		PLAYLISTS: 'Playlists',
-		ANON: 'aNONradio.net',
+		PLAYLISTS: CategoryControl('Playlists', 'p'),
+		ANON: CategoryControl('aNONradio.net', 'n'),
+		INTERNET: CategoryControl('internet-radio.com', 'i'),
 	})
 
 	COMMON_CONTROLS = OrderedDict({
@@ -315,13 +261,13 @@ class iHeart_CLI(iHeart):
 
 	CONTROLS = COMMON_CONTROLS.copy() # this copy might be modified downstream according to type of station
 
-	def __init__(self, configdir, debug=False):
+	def __init__(self, configdir):
 		uuid_file = os.path.join(configdir, "iheart-api.uuid")
-		super().__init__(uuid_store=uuid_file, print_url=False)
-		self.store = iHeart_Storage(configdir=configdir, debug=debug)
+		super().__init__(uuid_filepath=uuid_file)
+		self.store = iRadio_Storage(configdir=configdir)
 		self.station_list = []
 		self._station = None
-		self._debug = debug
+		self._debug = os.environ.get('RADIO_DEBUG') == "1"
 
 
 	def print_help(self):
@@ -333,17 +279,19 @@ class iHeart_CLI(iHeart):
 	@property
 	def category(self):
 		# category getter to convert current station to it's category
-		if isinstance(self.station, LiveStation):
+		if isinstance(self.station, iHeartLiveStation):
 			return self.STATIONS
 		# ArtistStation should be checked for after checking for it's subclasses - SongStation and Playlist
-		elif isinstance(self.station, SongStation):
+		elif isinstance(self.station, iHeartSongStation):
 			return self.TRACKS
-		elif isinstance(self.station, Playlist):
+		elif isinstance(self.station, LocalPlaylist):
 			return self.PLAYLISTS
-		elif isinstance(self.station, ArtistStation):
+		elif isinstance(self.station, iHeartArtistStation):
 			return self.ARTISTS
 		elif isinstance(self.station, aNONradio):
 			return self.ANON
+		elif isinstance(self.station, InternetRadio):
+			return self.INTERNET
 		else:
 			return None
 
@@ -356,15 +304,15 @@ class iHeart_CLI(iHeart):
 	def station(self, station):
 		# Modifying controls based on selected station type
 		self.CONTROLS = self.COMMON_CONTROLS.copy()
-		if isinstance(station, Playlist):
+		if isinstance(station, LocalPlaylist):
 			self.CONTROLS['s'] = 'shuffle-playlist-toggle' # No search when in playlists, instead, use 's' for shuffle
 			self.CONTROLS['l'] = 'list-playlist-tracks' # List tracks when in playlists
 			self.CONTROLS['j'] = 'jump-to-track' # Jump to track by index in playlist
 			self.CONTROLS['d'] = 'delete-from-playlist' # Delete track from playlist
-		elif isinstance(station, LiveStation):
+		elif isinstance(station, iHeartLiveStation):
 			del self.CONTROLS['+'] # Cannot add live stations to playlists
 			del self.CONTROLS['r'] # Cannot repeat track in live stations
-		elif isinstance(station, aNONradio):
+		elif isinstance(station, (aNONradio, InternetRadio)):
 			del self.CONTROLS['+'] # Cannot add live stations to playlists
 			del self.CONTROLS['r'] # Cannot repeat track in aNONradio stations
 			del self.CONTROLS['s'] # Cannot search track in aNONradio stations
@@ -383,6 +331,9 @@ class iHeart_CLI(iHeart):
 		if category == self.ANON:
 			return aNONradio()
 
+		if category == self.INTERNET:
+			return InternetRadio()
+
 		elif category == self.PLAYLISTS:
 			# highjacking playlist category for Json stored implementation
 			return self.choose_playlist()
@@ -394,24 +345,21 @@ class iHeart_CLI(iHeart):
 		print("Pick a category -")
 		pl = self.store.get_playlists()
 		playlist_count = len(pl)
-		cat_names = []
-		cats_consts = []
-		for c in self.CATEGORIES:
+		cats_consts = {}
+		for c, ctrl in self.CATEGORIES.items():
 			if c==self.PLAYLISTS and playlist_count==0:
 				continue
-			cats_consts.append(c)
-			cat_names.append(self.CATEGORIES[c])
+			cats_consts[ctrl.shorthand] = c
 
-		for i, s in enumerate(cat_names):
-			print("\t", app_msg_color(str(i)), ")", s)
+			print("\t", app_msg_color(str(ctrl.shorthand)), ")", ctrl.name)
 		try:
 			choice = input("Pick: ").strip()
 			if choice == '':
-				choice = 0 # default choice
-			elif not choice or not choice.isnumeric() or int(choice)>=len(cat_names):
+				choice = cats_consts.keys()[0] # default choice
+			elif not choice or choice not in cats_consts:
 				_print_error("Invalid choice!")
 				raise Exception("Invalid choice!")
-			return cats_consts[int(choice)]
+			return cats_consts[choice]
 		except Exception as e:
 			if self._debug: print(e)
 			if force:
@@ -446,7 +394,7 @@ class iHeart_CLI(iHeart):
 	def search_stations(self, category, keyword=None):
 		try:
 			if keyword is None:
-				keyword = input("Search {}: ".format(self.CATEGORIES[category]))
+				keyword = input("Search {}: ".format(self.CATEGORIES[category].name))
 			if not keyword.strip():
 				raise Exception("No keyword provided")
 			return self.list_current_stations(getter=lambda startIndex:self.search(keyword.strip(), category=category, startIndex=startIndex))
@@ -456,14 +404,16 @@ class iHeart_CLI(iHeart):
 
 
 	def list_current_stations(self, getter=None):
+		'''
+		This method takes an input function 'getter'
+		- the getter must take start index as argument and return a list of stations.
+			this allows for pagination type workflow
+		'''
 		try:
 			new_search = (getter is not None)
 			is_playing = self.station is not None and self.station.is_playing()
 			if new_search:
-				msg = "Enter 'm' to list more results."
-				if not is_playing:
-					msg += "\nPress Enter key to select choice 0."
-				print(app_msg_color(msg))
+				print(app_msg_color("Enter 'm' to list more results."))
 				self.station_list = []
 
 			while True:
@@ -485,7 +435,10 @@ class iHeart_CLI(iHeart):
 						idx += cur_st_len
 					print("\t", app_msg_color(str(idx)), ")", s.name)
 
-				choice = input("Choice: ").strip()
+				choice_msg = "Choice: "
+				if not is_playing:
+					choice_msg = f"Choice {app_msg_color('(default 0)')}: "
+				choice = input(choice_msg).strip()
 				if choice == '' and not is_playing:
 					choice = 0 # default choice if not playing anything
 				elif choice == 'm' and new_search:
@@ -529,12 +482,14 @@ class iHeart_CLI(iHeart):
 				print(app_msg_color("+ {}".format(pl)))
 
 		except Exception as e:
-			if self._debug: print(e)
+			_print_error(str(e))
+			if self._debug:
+				traceback.print_exc()
 
 
 	def delete_from_playlist(self):
 		'''deletes current track from playlist'''
-		if not isinstance(self.station, Playlist) or self.station.now_playing_id is None: # only works if current station is a playlist
+		if not isinstance(self.station, LocalPlaylist) or self.station.now_playing_id is None: # only works if current station is a playlist
 			return None
 		try:
 			choice = input(app_msg_color(f"Delete current track from '{self.station.name}'? (y/n): ")).strip()
@@ -557,7 +512,7 @@ class iHeart_CLI(iHeart):
 		try:
 			pl = self.store.get_playlists()
 			pl_dict = {'name': playlist_name, 'track_dict_list': list(pl[playlist_name].values())}
-			return Playlist(pl_dict)
+			return LocalPlaylist(pl_dict)
 		except Exception as e:
 			if self._debug: print(e)
 		return None
@@ -570,9 +525,7 @@ class iHeart_CLI(iHeart):
 				print("\t", app_msg_color(str(i)), ")", t)
 
 			choice = input("Choice: ").strip()
-			if choice == '':
-				choice = 0 # default choice
-			elif not choice or not choice.isnumeric() or int(choice)>=len(self.station.track_list):
+			if not choice or not choice.isnumeric() or int(choice)>=len(self.station.track_list):
 				_print_error("Invalid choice!")
 				raise Exception("Invalid choice!")
 			self.station.jump_to(int(choice))
@@ -625,10 +578,10 @@ class iHeart_CLI(iHeart):
 
 					elif cmd == 'print-current':
 						self.station.show_time(False)
-						if isinstance(self.station, (LiveStation, aNONradio)):
-							print(self.station)
-						else:
+						if hasattr(self.station, 'current_track'):
 							print(self.station.current_track)
+						else:
+							print(self.station)
 
 					elif cmd == 'change-category':
 						self.station.show_time(False)
@@ -703,16 +656,18 @@ def main():
 	parser = argparse.ArgumentParser("iheart")
 	parser.add_argument("-v", '--version', help="show version and exit", action="store_true")
 	parser.add_argument("-d", '--debug', help="enable debug messages", action="store_true")
-	parser.add_argument('--no-color', help="Disable color output", action="store_true")
+	parser.add_argument("-c", '--config-path', help="show config path and exit", action="store_true")
+	parser.add_argument('--no-color', help="disable color output", action="store_true")
 
 	group = parser.add_mutually_exclusive_group(required=False)
 	group.add_argument("-a", "--artist", help="search Artist radio with provided artist name")
 	group.add_argument("-s", "--song", help="search Song radio with provided song name")
 	group.add_argument("-l", "--live", help="search Live radio with provided station name")
 	group.add_argument("-p", "--playlist", help="play selected local playlist (exact name required)")
-	parser.add_argument("--shuffle", help="start playlist in shuffle mode (only works while --playlist is specified)", action='store_true')
-	group.add_argument("--anon", help="play aNONradio.net", action="store_true")
+	group.add_argument("-n", "--anon", help="play aNONradio.net", action="store_true")
+	group.add_argument("-i", "--internet-radio", help="play internet-radio.com", action="store_true")
 
+	parser.add_argument("--shuffle", help="start playlist in shuffle mode (only works when --playlist is specified)", action='store_true')
 	args = parser.parse_args()
 
 	if not vlc_is_installed():
@@ -720,10 +675,19 @@ def main():
 		print("It can be installed from https://www.videolan.org/\n")
 		return 1
 
+	if args.debug:
+		os.environ['RADIO_DEBUG'] = "1"
+	else:
+		os.environ['RADIO_DEBUG'] = "0"
+
 	if args.version:
 		print(__version__)
 		return None
 
+	if args.config_path:
+		print(DATADIR)
+		return None
+
 	if args.no_color or not Colors.supported():
 		Colors.DISABLED = True
 
@@ -748,22 +712,19 @@ def main():
 		category = iHeart_CLI.ANON
 		search_term = None
 
+	elif args.internet_radio is True:
+		category = iHeart_CLI.INTERNET
+		search_term = None
+
 	else:
 		category = None
 		search_term = None
 
-	configdir = os.path.join(
-		os.environ.get('APPDATA') or
-		os.environ.get('XDG_CONFIG_HOME') or
-		os.path.join(os.environ['HOME'], '.config'),
-		"iheartcli"
-	)
-	if not os.path.isdir(configdir): os.makedirs(configdir)
 
 	try:
 		# Welcome message
 		print(WELCOME_MSG)
-		radio = iHeart_CLI(configdir, debug=args.debug)
+		radio = iHeart_CLI(DATADIR)
 		if category == iHeart_CLI.PLAYLISTS:
 			# set the playlist if name is correct, else will be set to None
 			radio.station = radio.get_playlist_as_station(search_term)
